@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -34,7 +34,6 @@
 
 #include <LXQt/Settings>
 #include <LXQt/HtmlDelegate>
-#include <XdgIcon>
 #include <LXQt/PowerManager>
 #include <LXQt/ScreenSaver>
 #include <LXQtGlobalKeys/Action>
@@ -91,11 +90,11 @@ Dialog::Dialog(QWidget *parent) :
     ui->commandList->setItemDelegate(new LXQt::HtmlDelegate(QSize(32, 32), ui->commandList));
 
     // Popup menu ...............................
-    QAction *a = new QAction(XdgIcon::fromTheme("configure"), tr("Configure"), this);
+    QAction *a = new QAction(QIcon::fromTheme("configure"), tr("Configure"), this);
     connect(a, SIGNAL(triggered()), this, SLOT(showConfigDialog()));
     addAction(a);
 
-    a = new QAction(XdgIcon::fromTheme("edit-clear-history"), tr("Clear History"), this);
+    a = new QAction(QIcon::fromTheme("edit-clear-history"), tr("Clear History"), this);
     connect(a, SIGNAL(triggered()), mCommandItemModel, SLOT(clearHistory()));
     addAction(a);
 
