@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2010-2013 Razor team
  * Authors:
@@ -31,7 +31,6 @@
 
 #include "providers.h"
 #include "yamlparser.h"
-#include <XdgIcon>
 #include <XdgDesktopFile>
 #include <XdgMenu>
 #include <XmlHelper>
@@ -97,7 +96,7 @@ static QString which(const QString &progName)
 
     const QStringList dirs = QString(getenv("PATH")).split(":");
 
-    foreach (const QString &dir, dirs)
+    for (const QString &dir : dirs)
     {
         QFileInfo fileInfo(QDir(dir), progName);
         if (fileInfo.isExecutable() && fileInfo.isFile())
@@ -192,8 +191,8 @@ AppLinkItem::AppLinkItem(MenuCacheApp* app):
     MenuCacheItem* item = MENU_CACHE_ITEM(app);
     mIconName = QString::fromUtf8(menu_cache_item_get_icon(item));
     mTitle = QString::fromUtf8(menu_cache_item_get_name(item));
-    mComment = QString::fromUtf8(menu_cache_item_get_comment(item));
-    mToolTip = mComment;
+    mComment = QString::fromUtf8(menu_cache_app_get_generic_name(app));
+    mToolTip = QString::fromUtf8(menu_cache_item_get_comment(item));
     mCommand = menu_cache_app_get_exec(app);
     mProgram = QFileInfo(mCommand).baseName().section(" ", 0, 0);
     char* path = menu_cache_item_get_file_path(MENU_CACHE_ITEM(app));
@@ -214,7 +213,7 @@ void AppLinkItem::updateIcon()
 //    qDebug() << hex << this;
 //    qDebug() << Q_FUNC_INFO;
     if (mIcon.isNull())
-        mIcon = XdgIcon::fromTheme(mIconName);
+        mIcon = QIcon::fromTheme(mIconName);
 //    qDebug() << "*****************************************";
 }
 
@@ -271,8 +270,10 @@ bool AppLinkItem::compare(const QRegExp &regExp) const
     if (regExp.isEmpty())
         return false;
 
-    return mProgram.contains(regExp) ||
-           mTitle.contains(regExp) ;
+    return mProgram.contains(regExp)
+        || mTitle.contains(regExp)
+        || mComment.contains(regExp)
+        || mToolTip.contains(regExp);
 }
 
 
@@ -438,7 +439,7 @@ void AppLinkProvider::update()
 HistoryItem::HistoryItem(const QString &command):
         CommandProviderItem()
 {
-    mIcon = XdgIcon::defaultApplicationIcon();
+    mIcon = QIcon::fromTheme(QLatin1String("application-x-executable"));
     mTitle = command;
     mComment = QObject::tr("History");
     mCommand = command;
@@ -544,7 +545,7 @@ CustomCommandItem::CustomCommandItem(CustomCommandProvider *provider):
     CommandProviderItem(),
     mProvider(provider)
 {
-    mIcon = XdgIcon::fromTheme("utilities-terminal");
+    mIcon = QIcon::fromTheme("utilities-terminal");
 }
 
 
@@ -820,7 +821,7 @@ MathItem::MathItem():
         mParser{new Parser}
 {
     mToolTip =QObject::tr("Mathematics");
-    mIcon = XdgIcon::fromTheme("accessories-calculator");
+    mIcon = QIcon::fromTheme("accessories-calculator");
 }
 
 
@@ -924,7 +925,7 @@ bool ExternalProviderItem::setData(QMap<QString,QString> & data)
     mToolTip = data["tooltip"];
     mCommand = data["command"];
     if (data.contains("icon"))
-        mIcon = XdgIcon::fromTheme(data["icon"]);
+        mIcon = QIcon::fromTheme(data["icon"]);
 
     return true;
 }
@@ -966,8 +967,7 @@ void ExternalProvider::newListOfMaps(QList<QMap<QString,QString> > maps)
     qDeleteAll(*this);
     clear();
 
-    QMap<QString, QString> map;
-    foreach(map, maps)
+    for(auto map : qAsConst(maps))
     {
         ExternalProviderItem *item  = new ExternalProviderItem();
         if (item->setData(map))
